import 'dart:collection';
import 'dart:io';

import 'package:d_dio/src/http.dart';
import 'package:d_dio/src/utils/web.dart';

class BaseReq {
  late bool needToken; //是否需要token

  late String language;
  late String version;
  late String time;
  late String deviceId;
  late String ip;
  String? token;

  int get platform => WebUtils.isWeb ? 1 : 3;

  String get system => WebUtils.isWeb
      ? 'pc'
      : Platform.isIOS
          ? 'ios'
          : 'android';

  BaseReq({this.needToken = false}) {
    time = DateTime.now().millisecondsSinceEpoch.toString();

    language = http.cacheReader!('language', defaultValue: 'zh-CN')!;

    version = http.cacheReader!('version', defaultValue: '0.0.0')!;

    deviceId = http.cacheReader!('device_id', defaultValue: 'unknown')!;

    ip = http.cacheReader!('ip', defaultValue: '0.0.0.0')!;

    if (needToken) token = http.cacheReader!('token', defaultValue: '')!;
  }

  Map<String, dynamic> toJson() {
    final data = SplayTreeMap<String, dynamic>();
    data['language'] = language;
    data['platform'] = platform;
    data['system'] = system;
    data['version'] = version;
    data['time'] = time;
    data['device_id'] = deviceId;
    data['ip'] = ip;
    if (needToken) data['token'] = token;

    return data;
  }
}
