import 'dart:convert';

import 'package:d_dio/src/type/type.dart';
import 'package:d_dio/src/utils/interceptor_utils.dart';
import 'package:dio/dio.dart';

class CacheInterceptor extends InterceptorsWrapper {
  final Set<String> _cacheUrlPathSet = {};
  final CacheSaver cacheSaver;

  CacheInterceptor({required this.cacheSaver});

  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    bool openCache = InterceptorUtils.getCustomParams('_cache', options);
    if (openCache) _cacheUrlPathSet.add(options.path);
    super.onRequest(options, handler);
  }

  @override
  void onResponse(Response response, ResponseInterceptorHandler handler) {
    final path = response.requestOptions.path;
    if (_cacheUrlPathSet.contains(path)) {
      _cacheUrlPathSet.remove(path);
      cacheSaver.call('_http_cache_$path', jsonEncode(response.data));
    }
    super.onResponse(response, handler);
  }
}
