import 'dart:collection';

import 'package:d_dio/src/interceptor/formdata_interceptor.dart';
import 'package:d_dio/src/utils/encrypt_utils.dart';
import 'package:d_dio/src/utils/interceptor_utils.dart';
import 'package:d_dio/src/utils/log.dart';
import 'package:dio/dio.dart';

class SignInterceptor extends InterceptorsWrapper {
  final String secret;

  SignInterceptor({required this.secret});

  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    try {
      Map<String, dynamic> data = InterceptorUtils.getAllParams(options);

      ///使用formdata时 file部分不参与加密
      bool useFormData = InterceptorUtils.getCustomParams('_formData', options,
          removeAfterRead: false);
      if (useFormData) {
        data['sign'] =
            genSign(data, prefixIgnore: FormDataInterceptor.FILE_PREFIX);
      } else {
        data['sign'] = genSign(data);
      }
    } catch (e) {
      logger.d("SignInterceptor:$e");
    }
    super.onRequest(options, handler);
  }

  /// 参数排序生成sign 前缀为prefixRemove的字段不参与生成sign
  String genSign(Map<String, dynamic> map, {String? prefixIgnore}) {
    final mapTemp = <String, dynamic>{}..addAll(map);
    if (prefixIgnore != null) {
      mapTemp.removeWhere((key, value) => key.startsWith(prefixIgnore));
    }
    final stMap = SplayTreeMap<String, dynamic>()..addAll(mapTemp);
    final buffer = StringBuffer();
    stMap.forEach((key, value) {
      buffer
        ..write(key)
        ..write(value);
    });
    buffer.write(secret);
    return EncryptUtils.md5Encrypt(buffer.toString());
  }
}
